/*************************************************************************/
/*************************************************************************/
/*                                                                       */
/*  File Name : SCPCrossoverUniform.h                                    */
/*                                                                       */
/*       Date : March 4, 1998                                            */
/* Updated at : March 4, 1998                                            */
/*                                                                       */
/*     Author : H. Timucin OZDEMIR                                       */
/*                                                                       */
/*************************************************************************/
/** 
    Uniform Crossover:
    1. let p1 and p2 be parents and m denote the number of columns 
    4. for i=1 to m 
       4.1. generate a random number (r) in range [0,1.0]
       4.2. if( r>=0.5 ) then let o1[i]=p1[i] and o2[i]=p2[i]
       4.3. if( r< 0.5 ) then let o1[i]=p2[i] and o2[i]=p1[i]
    7. repair o1 if necessary and reduce if it is possible
    8. repair o2 if necessary and reduce if it is possible

Note: Because of various repair strategy, repair will be overloaded.
*/
/*************************************************************************/

#ifndef _SCPCrossoverUniform_h
#define _SCPCrossoverUniform_h

#include <CrossOverOperation.h>
#include <Chromosomes.h>
#include <ChromosomesBag.h>

#include "SetCoverSolution.h"

class SCPCrossoverUniform : public CrossOverOperation
{
   public :
      SCPCrossoverUniform();
      virtual ~SCPCrossoverUniform();
      virtual ChromosomesBag apply(Chromosomes*,Chromosomes*);
      virtual apply(Chromosomes*,Chromosomes*,Chromosomes**);
      ChromosomesBag applyOLD(Chromosomes*,Chromosomes*);
      virtual ChromosomesBag apply(Chromosomes*,Chromosomes*,float);

   protected:

      virtual void repair(SetCoverSolution*);

};// end of Class SCPCrossoverUniform

#endif
